@@ -1,4 +1,7 @@
 from . import hpm
 
+def main():
+    hpm.main()
+
 if __name__ == "__main__":
-    hpm.main()
\ No newline at end of file
+    main()
\ No newline at end of file
