@@ -1,6 +1,7 @@
 import requests
 import os
 import json
+import pathlib
 from typing import List
 from rich.console import Console
 from ._typing import Group, Project
@@ -9,7 +10,7 @@ BASE_URI = "https://gitedu.hesge.ch/api/v4"
 console = Console()
 
 try:
-    token = open("./config.txt", "r").read()
+    token = open(pathlib.Path(__file__).resolve().parent.absolute() / "config.txt", "r").read()
 except Exception as e:
     token = ""
 
