@@ -38,7 +38,7 @@ def main():
             print("Command `setup` require argument `--token`.")
             exit()
         
-        with open("./config.txt", "w+") as f:
+        with open(pathlib.Path(__file__).resolve().parent.absolute() / "config.txt", "w+") as f:
             f.write(args.token)
     elif args.command == "create-app":
         clr_scr()
